package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertChaAppl;

public interface IBisTtsaCertChaApplService {
    BisTtsaCertChaAppl selectBisTtsaCertChaApplByGuid(String guid);
    List<BisTtsaCertChaAppl> selectBisTtsaCertChaApplList(BisTtsaCertChaAppl bisTtsaCertChaAppl);
    int insertBisTtsaCertChaAppl(BisTtsaCertChaAppl bisTtsaCertChaAppl);
    int updateBisTtsaCertChaAppl(BisTtsaCertChaAppl bisTtsaCertChaAppl);
    int deleteBisTtsaCertChaApplByGuid(String guid);
    int deleteBisTtsaCertChaApplByGuids(String[] guids);
}
